# $URL: //local/member/autrijus/Parse-AFP/lib/Parse/AFP/PTX/SIM.pm $ $Author: autrijus $
# $Rev: 1130 $ $Date: 2004-02-17T15:40:29.640821Z $

package Parse::AFP::PTX::SIM;
use base 'Parse::AFP::PTX::ControlSequence';

use constant SUBFORMAT => (
    Data	=> 'n',
);

1;
